summaryrefslogtreecommitdiff
path: root/static_pool.go
diff options
context:
space:
mode:
authorWolfy-J <[email protected]>2018-04-15 12:48:06 +0300
committerWolfy-J <[email protected]>2018-04-15 12:48:06 +0300
commite2c1c66d7a35a9c60a4f05126691242068ebb589 (patch)
tree76db075971f2fe683ed3bf643bbf097b47178a5a /static_pool.go
parentf8ff7aeedc893969d02115d23b62503a75228446 (diff)
report instead of observe
Diffstat (limited to 'static_pool.go')
-rw-r--r--static_pool.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/static_pool.go b/static_pool.go
index c119a270..c4895bf0 100644
--- a/static_pool.go
+++ b/static_pool.go
@@ -70,8 +70,8 @@ func NewPool(cmd func() *exec.Cmd, factory Factory, cfg Config) (*StaticPool, er
return p, nil
}
-// Watch attaches pool event watcher.
-func (p *StaticPool) Watch(o func(event int, w *Worker, ctx interface{})) {
+// Report attaches pool event watcher.
+func (p *StaticPool) Report(o func(event int, w *Worker, ctx interface{})) {
p.observer = o
}